@@ -16,6 +16,7 @@ from biomaj.workflow import RemoveWorkflow
 from biomaj.workflow import RepairWorkflow
 from biomaj.workflow import Workflow
 from biomaj.workflow import ReleaseCheckWorkflow
+from biomaj.notify import Notify
 from biomaj_core.config import BiomajConfig
 from biomaj.options import Options
 from biomaj.process.processfactory import ProcessFactory
@@ -957,30 +958,36 @@ class Bank(object):
                 logging.error('Cannot remove bank, some production directories are freezed, use force if needed')
                 return False
 
+        self.load_session()
+
         self.banks.remove({'name': self.name})
         BmajIndex.delete_all_bank(self.name)
         bank_data_dir = self.get_data_dir()
         logging.warn('DELETE ' + bank_data_dir)
+        err_msg = ''
         if os.path.exists(bank_data_dir):
             try:
                 shutil.rmtree(bank_data_dir)
             except Exception:
                 logging.exception('Failed to delete bank directory: ' + bank_data_dir)
-                logging.error('Bank will be deleted but some files/dirs may still be present on system, you can safely manually delete them')
+                logging.error('Bank will be deleted but some files/dirs may still be present on %s, you can safely manually delete them' % bank_data_dir)
+                err_msg = 'Bank will be deleted but some files/dirs may still be present on %s, you can safely manually delete them' % bank_data_dir
         bank_offline_dir = os.path.join(self.config.get('data.dir'), self.config.get('offline.dir.name'))
         if os.path.exists(bank_offline_dir):
             try:
                 shutil.rmtree(bank_offline_dir)
             except Exception:
                 logging.exception('Failed to delete bank offline directory: ' + bank_offline_dir)
-                logging.error('Bank will be deleted but some files/dirs may still be present on system, you can safely manually delete them')
+                logging.error('Bank will be deleted but some files/dirs may still be present on %s, you can safely manually delete them' % bank_offline_dir)
+                err_msg = 'Bank will be deleted but some files/dirs may still be present on %s, you can safely manually delete them' % bank_offline_dir
         bank_log_dir = os.path.join(self.config.get('log.dir'), self.name)
         if os.path.exists(bank_log_dir) and self.no_log:
             try:
                 shutil.rmtree(bank_log_dir)
             except Exception:
                 logging.exception('Failed to delete bank log directory: ' + bank_log_dir)
-                logging.error('Bank will be deleted but some files/dirs may still be present on system, you can safely manually delete them')
+                logging.error('Bank will be deleted but some files/dirs may still be present on %s, you can safely manually delete them' % bank_log_dir)
+                err_msg = 'Bank will be deleted but some files/dirs may still be present on %s, you can safely manually delete them' % bank_log_dir
         end_time = datetime.now()
         end_time = time.mktime(end_time.timetuple())
         self.history.insert({
@@ -991,6 +998,12 @@ class Bank(object):
             'action': 'remove',
             'updated': None
         })
+
+        self.session._session['release'] = 'all'
+        self.session._session['status'][Workflow.FLOW_OVER] = True
+        self.session._session['update'] = False
+        self.session._session['remove'] = True
+        Notify.notifyBankAction(self, with_log=False, with_msg=err_msg)
         return True
 
     def get_status(self):
@@ -1218,7 +1231,7 @@ class Bank(object):
             set_to_false = False
             for task in self.session.flow:
                 # If task was in False status (KO) and we ask to start after this task, exit
-                if not set_to_false and not self.session.get_status(task['name']) and \
+                if not set_to_false and self.session.get_status(task['name']) is False and \
                         task['name'] != self.options.get_option('from_task'):
                     logging.error(
                         'Previous task ' + task['name'] + ' was not successful, cannot restart after this task')
