@@ -707,18 +707,18 @@ class UpdateWorkflow(Workflow):
                     params['protocol'] = str(cf.get('irods.protocol')).strip()
                     params['zone'] = str(cf.get('irods.zone')).strip()
 
-            # Protocol options: as for params, a field contains the name
+            # Options: as for params, a field contains the name
             # of the options (options.names) and the values are in another
             # field named options.<option_name>.
-            protocol_options = {}
+            options = {}
             option_names = cf.get('options.names')
             if option_names is not None:
                 option_names = option_names.split(',')
                 for option_name in option_names:
                     option_name = option_name.strip()
                     param = cf.get('options.' + option_name)
-                    protocol_options[option_name] = param.strip()
-                logging.debug("Protocol options: " + str(protocol_options))
+                    options[option_name] = param.strip()
+                logging.debug("Options: " + str(options))
 
             release_downloader = dserv.get_handler(
                 protocol,
@@ -733,7 +733,7 @@ class UpdateWorkflow(Workflow):
                 save_as=save_as,
                 timeout_download=cf.get('timeout.download'),
                 offline_dir=self.session.get_offline_directory(),
-                protocol_options=protocol_options
+                options=options
             )
 
             if protocol in ['directftp', 'directftps', 'directhttp', 'directhttps']:
@@ -753,23 +753,31 @@ class UpdateWorkflow(Workflow):
                 return False
 
             release_downloader.match([cf.get('release.file')], file_list, dir_list)
+
             if len(release_downloader.files_to_download) == 0:
                 logging.error('release.file defined but does not match any file')
                 self._close_download_service(dserv)
                 return False
-            if len(release_downloader.files_to_download) > 1:
-                logging.error('release.file defined but matches multiple files')
-                self._close_download_service(dserv)
-                return False
+
             if cf.get('release.regexp') is None or not cf.get('release.regexp'):
                 # Try to get from regexp in file name
-                rel = re.search(cf.get('release.file'), release_downloader.files_to_download[0]['name'])
+                rel = None
+                # if multiple files match release, get most recent file
+                if len(release_downloader.files_to_download) > 1:
+                    most_recent = Utils.get_more_recent_file(release_downloader.files_to_download)
+                    rel = re.search(cf.get('release.file'), most_recent['file']['name'])
+                else:
+                    rel = re.search(cf.get('release.file'), release_downloader.files_to_download[0]['name'])
                 if rel is None:
-                    logging.error('release.file defined but does not match any file')
+                    logging.error('release.file defined but could not match any file')
                     self._close_download_service(dserv)
                     return False
                 release = rel.group(1)
             else:
+                if len(release_downloader.files_to_download) > 1:
+                    logging.error('release.file defined but matches multiple files')
+                    self._close_download_service(dserv)
+                    return False
                 # Download and extract
                 tmp_dir = tempfile.mkdtemp('biomaj')
                 rel_files = release_downloader.download(tmp_dir)
@@ -879,14 +887,16 @@ class UpdateWorkflow(Workflow):
 
     def _load_local_files_from_session(self, session_id):
         """
-        Load lccal files for sessions from cache directory
+        Load local files for sessions from cache directory
         """
         cache_dir = self.bank.config.get('cache.dir')
         f_local_files = None
         file_path = os.path.join(cache_dir, 'local_files_' + str(session_id))
         if not os.path.exists(file_path):
+            logging.info("Workflow:wf_download:Cache:No cache file found for session %s, skipping" % (session_id))
             return f_local_files
 
+        logging.info("Workflow:wf_download:Cache:using %s" % (file_path))
         with open(file_path) as data_file:
             f_local_files = json.load(data_file)
 
@@ -1159,18 +1169,18 @@ class UpdateWorkflow(Workflow):
                 if cf.get('remote.file.' + str(i) + '.name'):
                     save_as = cf.get('remote.file.' + str(i) + '.name')
 
-                # Protocol options: as for params, a field contains the name
+                # Options: as for params, a field contains the name
                 # of the options (options.names) and the values are in another
                 # field named options.<option_name>.
-                protocol_options = {}
+                options = {}
                 option_names = cf.get('remote.file.' + str(i) + '.options.names')
                 if option_names is not None:
                     option_names = option_names.split(',')
                     for option_name in option_names:
                         option_name = option_name.strip()
                         param = cf.get('remote.file.' + str(i) + '.options.' + option_name)
-                        protocol_options[option_name] = param.strip()
-                    logging.debug("Protocol options: " + str(protocol_options))
+                        options[option_name] = param.strip()
+                    logging.debug("Options: " + str(options))
 
                 subdownloader = dserv.get_handler(
                     protocol,
@@ -1185,7 +1195,7 @@ class UpdateWorkflow(Workflow):
                     save_as=save_as,
                     timeout_download=cf.get('timeout.download'),
                     offline_dir=self.session.get_offline_directory(),
-                    protocol_options=protocol_options
+                    options=options
                 )
                 subdownloader.set_files_to_download(remotes)
 
@@ -1235,18 +1245,18 @@ class UpdateWorkflow(Workflow):
 
             save_as = cf.get('target.name')
 
-            # Protocol options: as for params, a field contains the name
+            # Options: as for params, a field contains the name
             # of the options (options.names) and the values are in another
             # field named options.<option_name>.
-            protocol_options = {}
+            options = {}
             option_names = cf.get('options.names')
             if option_names is not None:
                 option_names = option_names.split(',')
                 for option_name in option_names:
                     option_name = option_name.strip()
                     param = cf.get('options.' + option_name)
-                    protocol_options[option_name] = param.strip()
-                logging.debug("Protocol options: " + str(protocol_options))
+                    options[option_name] = param.strip()
+                logging.debug("Options: " + str(options))
 
             downloader = dserv.get_handler(
                 protocol,
@@ -1261,7 +1271,7 @@ class UpdateWorkflow(Workflow):
                 save_as=save_as,
                 timeout_download=cf.get('timeout.download'),
                 offline_dir=self.session.get_offline_directory(),
-                protocol_options=protocol_options
+                options=options
             )
 
             if protocol in ['directftp', 'directftps', 'directhttp', 'directhttps']:
@@ -1308,17 +1318,17 @@ class UpdateWorkflow(Workflow):
             for f in downloader.files_to_download:
                 if 'save_as' not in f or not f['save_as']:
                     f['save_as'] = f['name']
-                    for p in cf.get('remote.files', default='.*').split():
-                        if p == '.*' or p == '**/*':
-                            continue
-                        if p.startswith('^'):
-                            p = p.replace('^', '^/')
-                        else:
-                            p = '/' + p
-                        res = re.match(p, f['name'])
-                        if res is not None and res.groups() is not None and len(res.groups()) >= 1:
-                            f['save_as'] = '/'.join(res.groups())
-                            break
+                for p in cf.get('remote.files', default='.*').split():
+                    if p == '.*' or p == '**/*':
+                        continue
+                    if p.startswith('^'):
+                        p = p.replace('^', '^/')
+                    else:
+                        p = '/' + p
+                    res = re.match(p, f['name'])
+                    if res is not None and res.groups() is not None and len(res.groups()) >= 1:
+                        f['save_as'] = '/'.join(res.groups())
+                        break
 
             files_to_download += downloader.files_to_download
 
@@ -1458,6 +1468,8 @@ class UpdateWorkflow(Workflow):
             last_production_files = None
             if len(last_production_session['sessions']) > 0:
                 last_production_files = self._load_local_files_from_session(last_production_session['sessions'][0]['id'])
+            else:
+                logging.warn('Workflow:wf_download:no session found for last production id %s' % (last_production['session']))
 
             if not cf.get_bool('copy.skip', default=False):
                 for downloader in downloaders:
@@ -1475,6 +1487,7 @@ class UpdateWorkflow(Workflow):
             logging.debug('Workflow:wf_download:Copy files from ' + last_production_dir)
             for downloader in downloaders:
                 copied_files += downloader.files_to_copy
+                logging.info('Workflow:wf_download:Copying %d files from %s' % (len(downloader.files_to_copy), last_production_dir))
                 Utils.copy_files(
                     downloader.files_to_copy, offline_dir,
                     use_hardlinks=cf.get_bool('use_hardlinks', default=False)
@@ -1520,7 +1533,7 @@ class UpdateWorkflow(Workflow):
                 message.bank = self.name
                 message.session = session
                 message.local_dir = offline_dir
-                message.protocol_options.update(downloader.protocol_options)
+                message.options.update(downloader.options)
                 remote_file = downmessage_pb2.DownloadFile.RemoteFile()
                 protocol = downloader.protocol
                 remote_file.protocol = downmessage_pb2.DownloadFile.Protocol.Value(protocol.upper())
